!!! note
    Audiobooks are only available for the US, UK, Ireland, New Zealand and Australia markets.

::: spotify.api.API
    options:
      members:
        - get_chapter
        - get_several_chapters
::: spotify.models.SimpleChapter
::: spotify.models.Chapter
